%University of Texas at Arlington
%Non-determinism in Buck converter using Interval Matrices
%This m-file uses the INTLAB Toolbox, so save it in the same directory
%
% run startintlab.m %starts INTLAB
clear all
clc
%intvalinit('DisplayInfsup') %incase of endpoint notations
intvalinit('DisplayMidrad')%incase of midpoint radius notations
%load parameters
T = 1/60000;
Tmax = T*8000;
Vs = 100;
Vref = 48;
rs = 3.5;
rL = 520e-3;
Cr = 1.265; %correction applied to D to cater losses
D = Cr*Vref/Vs;
ohm = 10;%resistance mid value
hen = 2.65e-3;% inductance mid value
cap = 2.2e-3;% capcitance mid value
%interval matrices values
R = midrad(ohm,0.01*ohm);
L = midrad(hen,0.01*hen);
C = midrad(cap,0.01*cap);
%Transition matrices
Ac = [-1*(rs+rL)/L, -(1/L); (1/C), -(1/(R*C))];% switch closed
Bc = [(1/L); 0];
Ac_l = inf(Ac);
Ac_u = sup(Ac);
Bc_l = inf(Bc);
Bc_u = sup(Bc);

Ao = [-rL/L, -(1/L); (1/C), -(1/(R*C))];% switch open
Bo_l = [0; 0];
Bo_u = Bo_l;
Ao_l = inf(Ao);
Ao_u = sup(Ao);

Ad = [0, 0; 0, -(1/(R*C))];%For DCM
Bd_l = [0; 0];%For DCM
Bd_u = Bd_l; 
Ad_l = inf(Ad);
Ad_u = sup(Ad);

%%%set parameters for upper bounds
sys(1).Acu = Ac_u;
sys(1).Bcu = Bc_u;
sys(1).Aou = Ao_u;
sys(1).Bou = Bo_u;
sys(1).Adu = Ad_u;%For DCM
sys(1).Bdu = Bd_u;%For DCM
    
% set parameters in stateflow simulation
a00cu = sys(1).Acu(1,1);
a01cu = sys(1).Acu(1,2);
a10cu = sys(1).Acu(2,1);
a11cu = sys(1).Acu(2,2);
    
b0cu = sys(1).Bcu(1);
b1cu = sys(1).Bcu(2);
    
a00ou = sys(1).Aou(1,1);
a01ou = sys(1).Aou(1,2);
a10ou = sys(1).Aou(2,1);
a11ou = sys(1).Aou(2,2);
    
b0ou = sys(1).Bou(1);
b1ou = sys(1).Bou(2);
    
%DCM
    
a00du = sys(1).Adu(1,1);
a01du = sys(1).Adu(1,2);
a10du = sys(1).Adu(2,1);
a11du = sys(1).Adu(2,2);
    
b0du = sys(1).Bdu(1);
b1du = sys(1).Bdu(2);

%%%set parameters for lower bounds
sys(1).Acl = Ac_l;
sys(1).Bcl = Bc_l;
sys(1).Aol = Ao_l;
sys(1).Bol = Bo_l;
sys(1).Adl = Ad_l;%For DCM
sys(1).Bdl = Bd_l;%For DCM
    
% set parameters in stateflow simulation
a00cl = sys(1).Acl(1,1);
a01cl = sys(1).Acl(1,2);
a10cl = sys(1).Acl(2,1);
a11cl = sys(1).Acl(2,2);
    
b0cl = sys(1).Bcl(1);
b1cl = sys(1).Bcl(2);
    
a00ol = sys(1).Aol(1,1);
a01ol = sys(1).Aol(1,2);
a10ol = sys(1).Aol(2,1);
a11ol = sys(1).Aol(2,2);
    
b0ol = sys(1).Bol(1);
b1ol = sys(1).Bol(2);
    
%DCM
    
a00dl = sys(1).Adl(1,1);
a01dl = sys(1).Adl(1,2);
a10dl = sys(1).Adl(2,1);
a11dl = sys(1).Adl(2,2);
    
b0dl = sys(1).Bdl(1);
b1dl = sys(1).Bdl(2);